@@ -49,15 +49,12 @@
 #include "config.h"
 #endif
 
-#include "xaa.h"
-#include "xf86Cursor.h"
 #include "colormapst.h"
 #include "xf86.h"
 #include "xf86_OSproc.h"
 #include "mipointer.h"
 #include "mibstore.h"
 #include "micmap.h"
-#include "xf86DDC.h"
 #include "globals.h"
 #ifdef HAVE_XEXTPROTO_71
 #include <X11/extensions/dpmsconst.h>
@@ -70,8 +67,15 @@
 #include "xf86cmap.h"
 #include "shadowfb.h"
 
+#include "compat-api.h"
+
 #include <glide.h>
 
+/* glide3x does not define this alias anymore, so let's do it ourselves. */
+#ifndef GR_ZDEPTHVALUE_FARTHEST
+#define GR_ZDEPTHVALUE_FARTHEST 0
+#endif
+
 #define TRUE 1
 #define FALSE 0
 
@@ -87,30 +91,6 @@ typedef u8                 bool;
 
 #define GLIDEPTR(p) ((GLIDEPtr)((p)->driverPrivate))
 
-
-typedef FxBool (*pgrSstQueryBoards_t)(GrHwConfiguration*);
-typedef void (*pgrGlideInit_t)(void);
-typedef void (*pgrSstSelect_t)(int which_sst);
-typedef FxBool (*pgrSstWinOpen_t)(FxU32, GrScreenResolution_t, GrScreenRefresh_t, 
-                                  GrColorFormat_t, GrOriginLocation_t, int, int);
-typedef void (*pgrRenderBuffer_t)(GrBuffer_t);
-typedef void (*pgrClipWindow_t)(FxU32, FxU32, FxU32, FxU32);
-typedef void (*pgrBufferClear_t)(GrColor_t, GrAlpha_t, FxU16);
-typedef FxBool (*pgrLfbLock_t)(GrLock_t, GrBuffer_t, GrLfbWriteMode_t, GrOriginLocation_t, 
-                               FxBool, GrLfbInfo_t*);
-typedef FxBool (*pgrLfbUnlock_t)(GrLock_t, GrBuffer_t);
-typedef void (*pgrGlideShutdown_t)(void);
-
-
-#if defined(GLIDE3) && defined(GLIDE3_ALPHA)
-typedef FxBool (*pgrLfbWriteRegion_t)(GrBuffer_t, FxU32, FxU32, GrLfbSrcFmt_t, 
-                                     FxU32, FxU32, FxBool, FxI32, void*);
-#else
-typedef FxBool (*pgrLfbWriteRegion_t)(GrBuffer_t, FxU32, FxU32, GrLfbSrcFmt_t, 
-                                     FxU32, FxU32, FxI32, void*);
-#endif
-
-
 typedef struct {
   u8*                 ShadowPtr;
   u32                 ShadowPitch;
@@ -125,28 +105,16 @@ typedef struct {
   OptionInfoPtr       Options;
 } GLIDERec, *GLIDEPtr;
 
-static pgrSstQueryBoards_t pgrSstQueryBoards;
-static pgrGlideInit_t      pgrGlideInit;
-static pgrSstSelect_t      pgrSstSelect;
-static pgrSstWinOpen_t     pgrSstWinOpen;
-static pgrRenderBuffer_t   pgrRenderBuffer;
-static pgrClipWindow_t     pgrClipWindow;
-static pgrBufferClear_t    pgrBufferClear;
-static pgrLfbLock_t        pgrLfbLock;
-static pgrLfbUnlock_t      pgrLfbUnlock;
-static pgrGlideShutdown_t  pgrGlideShutdown;
-static pgrLfbWriteRegion_t pgrLfbWriteRegion;
-
 static const OptionInfoRec * GLIDEAvailableOptions(int chipid, int busid);
 static void	GLIDEIdentify(int flags);
 static Bool	GLIDEProbe(DriverPtr drv, int flags);
 static Bool	GLIDEPreInit(ScrnInfoPtr pScrn, int flags);
-static Bool	GLIDEScreenInit(int Index, ScreenPtr pScreen, int argc, char **argv);
-static Bool	GLIDEEnterVT(int scrnIndex, int flags);
-static void	GLIDELeaveVT(int scrnIndex, int flags);
-static Bool	GLIDECloseScreen(int scrnIndex, ScreenPtr pScreen);
+static Bool	GLIDEScreenInit(SCREEN_INIT_ARGS_DECL);
+static Bool	GLIDEEnterVT(VT_FUNC_ARGS_DECL);
+static void	GLIDELeaveVT(VT_FUNC_ARGS_DECL);
+static Bool	GLIDECloseScreen(CLOSE_SCREEN_ARGS_DECL);
 static Bool	GLIDESaveScreen(ScreenPtr pScreen, int mode);
-static void     GLIDEFreeScreen(int scrnIndex, int flags);
+static void     GLIDEFreeScreen(FREE_SCREEN_ARGS_DECL);
 static void     GLIDERefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
 static Bool     GLIDEModeInit(ScrnInfoPtr pScrn, DisplayModePtr mode);
 static void     GLIDERestore(ScrnInfoPtr pScrn, Bool Closing);
@@ -157,8 +125,6 @@ static void	GLIDEDisplayPowerManagementSet(ScrnInfoPtr pScrn,
                                                int flags);
 
 
-static int LoadGlide(void);
-
 #define GLIDE_VERSION 4000
 #define GLIDE_NAME "GLIDE"
 #define GLIDE_DRIVER_NAME "glide"
@@ -202,26 +168,6 @@ static SymTabRec GLIDEChipsets[] = {
 };
 
 
-/*
- * List of symbols from other modules that this module references.  This
- * list is used to tell the loader that it is OK for symbols here to be
- * unresolved providing that it hasn't been told that they haven't been
- * told that they are essential via a call to xf86LoaderReqSymbols() or
- * xf86LoaderReqSymLists().  The purpose is this is to avoid warnings about
- * unresolved symbols that are not required.
- */
-
-static const char *fbSymbols[] = {
-  "fbScreenInit",
-  "fbPictureInit",
-  NULL
-};
-
-static const char *shadowSymbols[] = {
-  "ShadowFBInit",
-  NULL
-};
-
 #ifdef XFree86LOADER
 
 static MODULESETUPPROTO(glideSetup);
@@ -246,59 +192,15 @@ static pointer
 glideSetup(pointer module, pointer opts, int *errmaj, int *errmin)
 {
   static Bool setupDone = FALSE;
-  pointer ret;
   int errmaj2 = 0, errmin2 = 0;
     
   if (!setupDone) 
   {
-    /*
-     * Modules that this driver always requires may be loaded here
-     * by calling LoadSubModule().
-     */
-
-    ret = LoadSubModule(module, "glide2x", NULL, NULL, EXTERN_MODULE, NULL,
-			&errmaj2, &errmin2);
-    if (!ret)
-    {
-      xf86Msg(X_ERROR, "Glide driver:\n"
-"\n"
-"Could not load the shared library file for Glide: \"libglide2x.so\"! \n"
-"\n"
-"You need to have Glide installed to run the glide driver for X.Org.\n"
-"Also, you need to tell X.Org where the libglide2x.so file is placed\n"
-"by making a soft link in the " MODULEDIR " directory that points\n"
-"to the libglide2x.so file. For example (if your libglide2x.so file is in\n"
-"/usr/lib):\n"
-"\n"
-"  # ln -s /usr/lib/libglide2x.so " MODULEDIR "\n"
-"\n"
-"\n");
-      if (errmaj)
-        *errmaj = LDR_NOSUBENT;
-      if (errmin)
-        *errmin = errmaj2;
-      return NULL;
-    }
-
-    if (!LoadGlide()) {
-      if (errmaj)
-        *errmaj = LDR_MODSPECIFIC;
-      if (errmin)
-        *errmin = 0;
-      return NULL;
-    }
-
     setupDone = TRUE;
     /* This module should be loaded only once */
     *errmaj = LDR_ONCEONLY;
     xf86AddDriver(&GLIDE, module, 0);
 
-    /*
-     * Tell the loader about symbols from other modules that this module
-     * might refer to.
-     */
-    LoaderRefSymLists(fbSymbols, shadowSymbols, NULL);
-
     /*
      * The return value must be non-NULL on success even though there
      * is no TearDownProc.
@@ -337,7 +239,7 @@ GLIDEFreeRec(ScrnInfoPtr pScrn)
 {
   if (pScrn->driverPrivate == NULL)
     return;
-  xfree(pScrn->driverPrivate);
+  free(pScrn->driverPrivate);
   pScrn->driverPrivate = NULL;
 }
 
@@ -355,13 +257,45 @@ GLIDEIdentify(int flags)
   xf86PrintChipsets(GLIDE_NAME, "driver for Glide devices (Voodoo cards)", GLIDEChipsets);
 }
 
+#if defined(GLIDE3)
+static int
+glide_get_num_boards(void)
+{
+  FxI32 num_sst;
+  int r;
+
+  r = grGet(GR_NUM_BOARDS, sizeof(num_sst), &num_sst);
+  if (!r)
+  {
+    xf86Msg(X_ERROR, "GLIDEProbe(): Error calling grGet(GR_NUM_BOARDS)!\n");
+    return -1;
+  }
+
+  return num_sst;
+}
+#else
+static int
+glide_get_num_boards(void)
+{
+  GrHwConfiguration hw;
+  int r;
+
+  r = grSstQueryBoards(&hw);
+  if (!r)
+  {
+    xf86Msg(X_ERROR, "GLIDEProbe(): Error calling grSstQueryBoards!\n");
+    return -1;
+  }
+
+  return hw.num_sst;
+}
+#endif
 
 /* Mandatory */
 static Bool
 GLIDEProbe(DriverPtr drv, int flags)
 {
-  GrHwConfiguration hw;
-  int i, sst, r;
+  int i, num_sst, sst;
   GDevPtr *devList;
   GDevPtr dev = NULL;
   int numdevList;
@@ -372,21 +306,17 @@ GLIDEProbe(DriverPtr drv, int flags)
   if ((numdevList = xf86MatchDevice(GLIDE_DRIVER_NAME, &devList)) <= 0)
     return FALSE;
 
-  r = pgrSstQueryBoards(&hw);
-  if (!r)
-  {
-    xf86Msg(X_ERROR, "GLIDEProbe(): Error calling pgrSstQueryBoards!\n");
+  num_sst = glide_get_num_boards();
+  if (num_sst < 0)
     goto cleanup;
-  }
-  
-  
-  /* hw.num_sst : number of Glide boards available */
-  if (hw.num_sst > 0 && (flags & PROBE_DETECT)) {
+
+  /* num_sst: number of Glide boards available */
+  if (num_sst > 0 && (flags & PROBE_DETECT)) {
     /* XXX Need to call xf886AddDeviceToConfigure() here */
     return TRUE;
   }
 
-  for (sst = 0; sst < hw.num_sst; sst++)
+  for (sst = 0; sst < num_sst; sst++)
   {
     for (i = 0; i < numdevList; i++)
     {
@@ -401,6 +331,8 @@ GLIDEProbe(DriverPtr drv, int flags)
 
         /* Allocate a ScrnInfoRec and claim the slot */
         if ((pScrn = xf86AllocateScreen(drv, 0))) {
+	    GLIDEPtr pGlide;
+
 	    xf86AddEntityToScreen(pScrn, entityIndex);
 	    
 	    /* I'm not going to "claim" the glide device since no other driver than this can drive it */
@@ -417,7 +349,14 @@ GLIDEProbe(DriverPtr drv, int flags)
 	    pScrn->EnterVT	 = GLIDEEnterVT;
 	    pScrn->LeaveVT	 = GLIDELeaveVT;
 	    pScrn->FreeScreen    = GLIDEFreeScreen;
-	    pScrn->driverPrivate = (void*)sst;
+
+	    /* Allocate the GLIDERec driverPrivate */
+	    if (!GLIDEGetRec(pScrn))
+		break;
+
+	    pGlide = GLIDEPTR(pScrn);
+	    pGlide->SST_Index = sst;
+
 	    /*
 	     * XXX This is a hack because don't have the PCI info.  Set it as
 	     * an ISA entity with no resources.
@@ -430,7 +369,7 @@ GLIDEProbe(DriverPtr drv, int flags)
   }
 
  cleanup:
-  xfree(devList);
+  free(devList);
   return foundScreen;
 }
 	
@@ -445,7 +384,6 @@ GLIDEPreInit(ScrnInfoPtr pScrn, int flags)
   MessageType from;
   int i;
   ClockRangePtr clockRanges;
-  int sst;
 
   if (flags & PROBE_DETECT) return FALSE;
 
@@ -453,9 +391,6 @@ GLIDEPreInit(ScrnInfoPtr pScrn, int flags)
   if (pScrn->numEntities != 1)
     return FALSE;
 
-  sst = (int)(pScrn->driverPrivate);
-  pScrn->driverPrivate = NULL;
-
   /* Set pScrn->monitor */
   pScrn->monitor = pScrn->confScreen->monitor;
 
@@ -517,11 +452,6 @@ GLIDEPreInit(ScrnInfoPtr pScrn, int flags)
   /* We use a programmable clock */
   pScrn->progClock = TRUE;
 
-  /* Allocate the GLIDERec driverPrivate */
-  if (!GLIDEGetRec(pScrn)) {
-    return FALSE;
-  }
-
   pGlide = GLIDEPTR(pScrn);
 
   /* Get the entity */
@@ -531,7 +461,8 @@ GLIDEPreInit(ScrnInfoPtr pScrn, int flags)
   xf86CollectOptions(pScrn, NULL);
 
   /* Process the options */
-  if (!(pGlide->Options = xalloc(sizeof(GLIDEOptions))))
+  pGlide->Options = malloc(sizeof(GLIDEOptions));
+  if (pGlide->Options == NULL)
     return FALSE;
   memcpy(pGlide->Options, GLIDEOptions, sizeof(GLIDEOptions));
   xf86ProcessOptions(pScrn->scrnIndex, pScrn->options, pGlide->Options);
@@ -545,8 +476,6 @@ GLIDEPreInit(ScrnInfoPtr pScrn, int flags)
              "Voodoo card will be %s when exiting server.\n", 
              pGlide->OnAtExit ? "ON" : "OFF");
 
-  pGlide->SST_Index = sst;
-
   /*
    * If the user has specified the amount of memory in the XF86Config
    * file, we respect that setting.
@@ -633,14 +562,11 @@ GLIDEPreInit(ScrnInfoPtr pScrn, int flags)
     return FALSE;
   }
 
-  xf86LoaderReqSymLists(fbSymbols, NULL);
-
   /* Load the shadow framebuffer */
   if (!xf86LoadSubModule(pScrn, "shadowfb")) {
     GLIDEFreeRec(pScrn);
     return FALSE;
   }
-  xf86LoaderReqSymLists(shadowSymbols, NULL);
 
   return TRUE;
 }
@@ -649,7 +575,7 @@ GLIDEPreInit(ScrnInfoPtr pScrn, int flags)
 /* Mandatory */
 /* This gets called at the start of each server generation */
 static Bool
-GLIDEScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
+GLIDEScreenInit(SCREEN_INIT_ARGS_DECL)
 {
   ScrnInfoPtr pScrn;
   GLIDEPtr pGlide;
@@ -659,7 +585,7 @@ GLIDEScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
   /* 
    * First get the ScrnInfoRec
    */
-  pScrn = xf86Screens[pScreen->myNum];
+  pScrn = xf86ScreenToScrn(pScreen);
 
   pGlide = GLIDEPTR(pScrn);
 
@@ -769,9 +695,9 @@ GLIDEScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
 
 /* Mandatory */
 static Bool
-GLIDEEnterVT(int scrnIndex, int flags)
+GLIDEEnterVT(VT_FUNC_ARGS_DECL)
 {
-  ScrnInfoPtr pScrn = xf86Screens[scrnIndex];
+  SCRN_INFO_PTR(arg);
   return GLIDEModeInit(pScrn, pScrn->currentMode);
 }
 
@@ -784,9 +710,9 @@ GLIDEEnterVT(int scrnIndex, int flags)
 
 /* Mandatory */
 static void
-GLIDELeaveVT(int scrnIndex, int flags)
+GLIDELeaveVT(VT_FUNC_ARGS_DECL)
 {
-  ScrnInfoPtr pScrn = xf86Screens[scrnIndex];
+  SCRN_INFO_PTR(arg);
   GLIDERestore(pScrn, FALSE);
 }
 
@@ -799,19 +725,19 @@ GLIDELeaveVT(int scrnIndex, int flags)
 
 /* Mandatory */
 static Bool
-GLIDECloseScreen(int scrnIndex, ScreenPtr pScreen)
+GLIDECloseScreen(CLOSE_SCREEN_ARGS_DECL)
 {
-  ScrnInfoPtr pScrn = xf86Screens[scrnIndex];
+  ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
   GLIDEPtr pGlide = GLIDEPTR(pScrn);
 
   if (pScrn->vtSema)
       GLIDERestore(pScrn, TRUE);
-  xfree(pGlide->ShadowPtr);
+  free(pGlide->ShadowPtr);
 
   pScrn->vtSema = FALSE;
 
   pScreen->CloseScreen = pGlide->CloseScreen;
-  return (*pScreen->CloseScreen)(scrnIndex, pScreen);
+  return (*pScreen->CloseScreen)(CLOSE_SCREEN_ARGS);
 }
 
 
@@ -819,17 +745,17 @@ GLIDECloseScreen(int scrnIndex, ScreenPtr pScreen)
 
 /* Optional */
 static void
-GLIDEFreeScreen(int scrnIndex, int flags)
+GLIDEFreeScreen(FREE_SCREEN_ARGS_DECL)
 {
-  ScrnInfoPtr pScrn = xf86Screens[scrnIndex];
+  SCRN_INFO_PTR(arg);
   GLIDEPtr pGlide = GLIDEPTR(pScrn);
   /*
    * This only gets called when a screen is being deleted.  It does not
    * get called routinely at the end of a server generation.
    */
   if (pGlide && pGlide->ShadowPtr)
-    xfree(pGlide->ShadowPtr);
-  GLIDEFreeRec(xf86Screens[scrnIndex]);
+    free(pGlide->ShadowPtr);
+  GLIDEFreeRec(pScrn);
 }
 
 
@@ -843,13 +769,13 @@ GLIDESaveScreen(ScreenPtr pScreen, int mode)
   Bool unblank;
   
   unblank = xf86IsUnblank(mode);
-  pScrn = xf86Screens[pScreen->myNum];
+  pScrn = xf86ScreenToScrn(pScreen);
   pGlide = GLIDEPTR(pScrn);
   pGlide->Blanked = !unblank;
   if (unblank)
     GLIDERefreshAll(pScrn);
   else
-    pgrBufferClear(0, 0, GR_ZDEPTHVALUE_FARTHEST);
+    grBufferClear(0, 0, GR_ZDEPTHVALUE_FARTHEST);
 
   return TRUE;
 }
@@ -935,15 +861,15 @@ GLIDEModeInit(ScrnInfoPtr pScrn, DisplayModePtr mode)
 
 
   /* Initialize the video card */
-  pgrGlideInit();
-  pgrSstSelect(pGlide->SST_Index);
+  grGlideInit();
+  grSstSelect(pGlide->SST_Index);
 
-  r = pgrSstWinOpen(0,
-                    pGlide->grResolution,
-                    pGlide->grRefreshRate,
-                    GR_COLORFORMAT_ARGB,
-                    GR_ORIGIN_UPPER_LEFT,
-                    2, 0);
+  r = grSstWinOpen(0,
+                   pGlide->grResolution,
+                   pGlide->grRefreshRate,
+                   GR_COLORFORMAT_ARGB,
+                   GR_ORIGIN_UPPER_LEFT,
+                   2, 0);
   if (!r)
   {
     xf86DrvMsg(pScrn->scrnIndex, X_ERROR, "grSstWinOpen returned %d. "
@@ -951,9 +877,9 @@ GLIDEModeInit(ScrnInfoPtr pScrn, DisplayModePtr mode)
     return FALSE;
   }
 
-  pgrRenderBuffer(GR_BUFFER_FRONTBUFFER);
-  pgrClipWindow(0, 0, 1024, 768);
-  pgrBufferClear(0, 0, GR_ZDEPTHVALUE_FARTHEST);
+  grRenderBuffer(GR_BUFFER_FRONTBUFFER);
+  grClipWindow(0, 0, 1024, 768);
+  grBufferClear(0, 0, GR_ZDEPTHVALUE_FARTHEST);
 
   if (!r)
   {
@@ -977,35 +903,9 @@ GLIDERestore(ScrnInfoPtr pScrn, Bool Closing)
     return;
   pGlide->GlideInitiated = FALSE;
   pGlide->Blanked = TRUE;
-  pgrBufferClear(0, 0, GR_ZDEPTHVALUE_FARTHEST);
+  grBufferClear(0, 0, GR_ZDEPTHVALUE_FARTHEST);
   if (!Closing || !(pGlide->OnAtExit))
-    pgrGlideShutdown();
-}
-
-
-#define GLIDE_FIND_FUNC(x) \
-  p##x = (p##x##_t)LoaderSymbol(#x); \
-  if (!p##x) \
-  { \
-    xf86Msg(X_ERROR, "Could not find " #x "() in libglide2x.so.\n"); \
-    return FALSE; \
-  }
-
-static int
-LoadGlide(void)
-{
-  GLIDE_FIND_FUNC(grSstQueryBoards);
-  GLIDE_FIND_FUNC(grGlideInit);
-  GLIDE_FIND_FUNC(grSstSelect);
-  GLIDE_FIND_FUNC(grSstWinOpen);
-  GLIDE_FIND_FUNC(grRenderBuffer);
-  GLIDE_FIND_FUNC(grClipWindow);
-  GLIDE_FIND_FUNC(grBufferClear);
-  GLIDE_FIND_FUNC(grLfbLock);
-  GLIDE_FIND_FUNC(grLfbUnlock);
-  GLIDE_FIND_FUNC(grGlideShutdown);
-  GLIDE_FIND_FUNC(grLfbWriteRegion);
-  return TRUE;
+    grGlideShutdown();
 }
 
 static void
@@ -1029,13 +929,13 @@ GLIDERefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox)
       src = pGlide->ShadowPtr + (pbox->y1 * pGlide->ShadowPitch) + 
             (x1 * Bpp);
 #if defined(GLIDE3) && defined(GLIDE3_ALPHA)
-      pgrLfbWriteRegion(GR_BUFFER_FRONTBUFFER, x1, pbox->y1, 
-                        GR_LFB_SRC_FMT_565, x2-x1, pbox->y2-pbox->y1, FALSE,
-                        pGlide->ShadowPitch, src);
+      grLfbWriteRegion(GR_BUFFER_FRONTBUFFER, x1, pbox->y1,
+                       GR_LFB_SRC_FMT_565, x2-x1, pbox->y2-pbox->y1, FALSE,
+                       pGlide->ShadowPitch, src);
 #else
-      pgrLfbWriteRegion(GR_BUFFER_FRONTBUFFER, x1, pbox->y1, 
-                        GR_LFB_SRC_FMT_565, x2-x1, pbox->y2-pbox->y1, 
-                        pGlide->ShadowPitch, src);
+      grLfbWriteRegion(GR_BUFFER_FRONTBUFFER, x1, pbox->y1,
+                       GR_LFB_SRC_FMT_565, x2-x1, pbox->y2-pbox->y1,
+                       pGlide->ShadowPitch, src);
 #endif
       pbox++;
     }
@@ -1048,13 +948,13 @@ GLIDERefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox)
       src = pGlide->ShadowPtr + (pbox->y1 * pGlide->ShadowPitch) + 
             (pbox->x1 * Bpp);
 #if defined(GLIDE3) && defined(GLIDE3_ALPHA)
-      pgrLfbWriteRegion(GR_BUFFER_FRONTBUFFER, x1, pbox->y1, 
-                        GR_LFB_SRC_FMT_888, x2-x1, pbox->y2-pbox->y1, FALSE,
-                        pGlide->ShadowPitch, src);
+      grLfbWriteRegion(GR_BUFFER_FRONTBUFFER, x1, pbox->y1,
+                       GR_LFB_SRC_FMT_888, x2-x1, pbox->y2-pbox->y1, FALSE,
+                       pGlide->ShadowPitch, src);
 #else
-      pgrLfbWriteRegion(GR_BUFFER_FRONTBUFFER, x1, pbox->y1, 
-                        GR_LFB_SRC_FMT_888, x2-x1, pbox->y2-pbox->y1, 
-                        pGlide->ShadowPitch, src);
+      grLfbWriteRegion(GR_BUFFER_FRONTBUFFER, x1, pbox->y1,
+                       GR_LFB_SRC_FMT_888, x2-x1, pbox->y2-pbox->y1,
+                       pGlide->ShadowPitch, src);
 #endif
       pbox++;
     }
@@ -1093,7 +993,7 @@ GLIDEDisplayPowerManagementSet(ScrnInfoPtr pScrn, int PowerManagementMode,
   case DPMSModeStandby:
   case DPMSModeSuspend:
     pGlide->Blanked = TRUE;
-    pgrBufferClear(0, 0, GR_ZDEPTHVALUE_FARTHEST);
+    grBufferClear(0, 0, GR_ZDEPTHVALUE_FARTHEST);
     break;
   case DPMSModeOff:
     GLIDERestore(pScrn, FALSE);
